@@ -8,8 +8,8 @@
 #define ISOTOPEGUIDEVIEW_H
 
 #include <QGraphicsView>
-#include <QResizeEvent>
 #include <QMouseEvent>
+#include <QResizeEvent>
 
 #include "isotopeview.h"
 
@@ -25,7 +25,7 @@ protected:
     void drawForeground(QPainter *painter, const QRectF &rect) override;
 
 private:
-    IsotopeView *m_guidedView;
+    IsotopeView *m_guidedView = nullptr;
     double m_zoomLevel;
     double m_scale;
     QPolygonF m_visibleSceneRect;
@@ -37,6 +37,9 @@ private:
     void mouseReleaseEvent(QMouseEvent *event) override;
     void mouseMoveEvent(QMouseEvent *event) override;
 
+public Q_SLOTS:
+    void updateScene();
+
 private Q_SLOTS:
     void setZoomLevel(double zoomLevel);
     void setVisibleSceneRect(const QPolygonF &sceneRect);
